@@ -31,13 +31,13 @@
 import json
 import glob
 
-import pwem
 import pyworkflow.utils as pwutils
 from pyworkflow import Config
 from pyworkflow.object import Integer
 import pyworkflow.protocol.params as params
 import pyworkflow.protocol.constants as cons
 from pwem.protocols import ProtParticlePickingAuto
+import pwem.objects as emobj
 
 from sphire import Plugin
 import sphire.convert as convert
@@ -49,7 +49,7 @@ class SphireProtCRYOLOPicking(ProtParticlePickingAuto):
     either manually or in a supervised mode.
     """
     _label = 'cryolo picking'
-    boxSizeEstimated = False
+
 
     def __init__(self, **args):
         ProtParticlePickingAuto.__init__(self, **args)
@@ -137,6 +137,13 @@ class SphireProtCRYOLOPicking(ProtParticlePickingAuto):
                             " crYOLO can use multiple GPUs - in that case"
                             " set to i.e. *0 1 2*.")
 
+        form.addParam('boxSizeFactor', params.FloatParam,
+                      default=1,
+                      expertLevel=cons.LEVEL_ADVANCED,
+                      label="Adjust estimated box size by",
+                      help="Value to multiply crYOLO estimated box size to be registered in the "
+                            "SetOfCoordinates. It is usually very tight to make a later extraction")
+
         form.addParallelSection(threads=1, mpi=1)
 
         self._defineStreamingParams(form)
@@ -225,8 +232,11 @@ class SphireProtCRYOLOPicking(ProtParticlePickingAuto):
             if self.boxSize.get():  # Box size can be provided by the user
                 boxSize = self.boxSize.get()
             else:  # If not crYOLO estimates it
-                self.boxSizeEstimated = True
                 boxSize = self._getEstimatedBoxSize()
+
+                if self.boxSizeFactor.get() != 1:
+                    boxSize = int(boxSize * self.boxSizeFactor.get())
+
             outputCoords.setBoxSize(boxSize)
 
         # Calculate if flip is needed
@@ -234,19 +244,39 @@ class SphireProtCRYOLOPicking(ProtParticlePickingAuto):
         # to open the image file each time for checking this
         yFlipHeight = convert.getFlipYHeight(micDoneList[0].getFileName())
 
-        for mic in micDoneList:
-            coordsFile = os.path.join(outDir, convert.getMicIdName(mic, '.cbox'))
-            if os.path.exists(coordsFile):
-                convert.readMicrographCoords(mic, outputCoords, coordsFile, boxSize,
-                                             yFlipHeight=yFlipHeight,
-                                             boxSizeEstimated=self.boxSizeEstimated)
+        # Create a reader to parse .cbox files
+        # and a Coordinate object to add to output set
+        reader = convert.CoordBoxReader(boxSize,
+                                        yFlipHeight=yFlipHeight,
+                                        boxSizeEstimated=self.boxSizeEstimated)
+        coord = emobj.Coordinate()
+        coord._cryoloScore = emobj.Float()
 
-    def createOutputStep(self):
+        for mic in micDoneList:
+            cboxFile = convert.getMicIdName(mic, suffix='.cbox')
+            coordsFile = os.path.join(outDir, cboxFile)
+            if os.path.exists(coordsFile):
+                reader.open(coordsFile)
+                for x, y, score in reader.iterCoords():
+                    # Clean up objId to add as a new coordinate
+                    coord.setObjId(None)
+                    coord.setPosition(x, y)
+                    coord.setMicrograph(mic)
+                    coord._cryoloScore.set(score)
+                    # Add it to the set
+                    outputCoords.append(coord)
+                reader.close()
+
+        # Register box size
+        self.createBoxSizeOutput(outputCoords)
+
+    def createBoxSizeOutput(self, coordSet):
         """ The output is just an Integer. Other protocols can use it in those
             IntParam if it has set allowsPointer=True
         """
-        boxSize = Integer(self.outputCoordinates.getBoxSize())
-        self._defineOutputs(boxsize=boxSize)
+        if not hasattr(self, "boxsize"):
+            boxSize = Integer(coordSet.getBoxSize())
+            self._defineOutputs(boxsize=boxSize)
 
     # --------------------------- INFO functions ------------------------------
     def _summary(self):
@@ -303,6 +333,11 @@ class SphireProtCRYOLOPicking(ProtParticlePickingAuto):
         return cites
 
     # -------------------------- UTILS functions ------------------------------
+    @property
+    def boxSizeEstimated(self):
+        # Only when boxSize == 0 it is estimated by cryolo
+        return self.boxSize.get() == 0
+
     def getInputModel(self):
         if self.inputModelFrom == INPUT_MODEL_GENERAL:
             m = Plugin.getCryoloGeneralModel()
